pub type PathResolverMap<F> = HashMap<String, PathResolver<F>>;Expand description
Map from path string to its resolver. Parser looks up each path in the expression in this map; if a path is missing, parsing fails with an error.
Aliased Type
pub struct PathResolverMap<F> { /* private fields */ }